__project__ = 'hermes-audio-server'
__description__ = 'An open source implementation of the audio server part of the Hermes protocol'
__keywords__ = 'hermes snips python3 rhasspy audio-player audio-recorder audio-server snips-audio-server hermes-protocol voice voice-control'
__author__ = 'Koen Vervloesem'
__email__ = 'koen@vervloesem.eu'
__license__ = 'MIT License'
__github_url__ = 'https://github.com/koenvervloesem/hermes-audio-server'
__doc_url__ = 'https://github.com/koenvervloesem/hermes-audio-server/README.md'
__tracker_url__ = 'https://github.com/koenvervloesem/hermes-audio-server/issues'
__player__ = 'hermes-audio-player'
__recorder__ = 'hermes-audio-recorder'
__version__ = '0.0.2'
